@@ -12,6 +12,7 @@ import traceback
 import struct
 import pymem
 import logging
+import urllib.parse
 from typing import Dict, Any
 
 from CommonClient import CommonContext, server_loop, gui_enabled, ClientCommandProcessor, logger, get_base_parser
@@ -403,9 +404,9 @@ class AnimalWellContext(CommonContext):
     command_processor = AnimalWellCommandProcessor
     items_handling = 0b111  # get sent remote and starting items
 
-    def __init__(self, server_address, slot_name, password, ready_callback=None, error_callback=None):
+    def __init__(self, server_address, password, ready_callback=None, error_callback=None):
         super().__init__(server_address, password)
-        self.username = slot_name
+        self.username = urllib.parse.urlparse(server_address).username
         self.ready_callback = ready_callback
         self.error_callback = error_callback
         self.game = "ANIMAL WELL"
@@ -1657,14 +1658,14 @@ async def console_task(ctx: AnimalWellContext):
         await asyncio.sleep(1/120)
 
 
-def launch(server_address: str = None, slot_name: str = None, password: str = None, ready_callback=None, error_callback=None):
+def launch(server_address: str = None, password: str = None, ready_callback=None, error_callback=None):
     """
     Launch the client
     """
     logging.getLogger("AnimalWellClient")
 
     async def main():
-        ctx = AnimalWellContext(server_address, slot_name, password, ready_callback, error_callback)
+        ctx = AnimalWellContext(server_address, password, ready_callback, error_callback)
         if ctx._can_takeover_existing_gui():
             await ctx._takeover_existing_gui() 
         else:
@@ -1724,6 +1725,6 @@ def launch(server_address: str = None, slot_name: str = None, password: str = No
             error_callback()
 
 
-def main(server_address: str = None, slot_name: str = None, password: str = None, ready_callback=None, error_callback=None):
+def main(server_address: str = None, password: str = None, ready_callback=None, error_callback=None):
     """Main entry point for integration with MultiWorld system"""
-    launch(server_address, slot_name, password, ready_callback, error_callback)
+    launch(server_address, password, ready_callback, error_callback)
